@@ -1,11 +1,3 @@
-/*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
- *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
- */
-
 /*
  * -----------------------------------------------------------------------------
  *
@@ -34,16 +26,20 @@
  *
  * -----------------------------------------------------------------------------
  */
-
+/*
+ * Hosted at http://sourceforge.net/projects/squidkerbauth
+ */
 #include "squid.h"
 #include "helpers/defines.h"
-#include "rfc1738.h"
 #include "util.h"
+#include "rfc1738.h"
 
-#if HAVE_LDAP
+#ifdef HAVE_LDAP
 
 #include "support.h"
-#include <cctype>
+#ifdef HAVE_CTYPE_H
+#include <ctype.h>
+#endif
 
 void
 init_args(struct main_args *margs)
@@ -171,6 +167,7 @@ main(int argc, char *const argv[])
     char *user, *domain, *group;
     char *up=NULL, *dp=NULL, *np=NULL;
     char *nuser, *nuser8 = NULL, *netbios;
+    char *c;
     int opt;
     struct main_args margs;
 
@@ -301,7 +298,6 @@ main(int argc, char *const argv[])
         exit(1);
     }
     while (1) {
-        char *c;
         if (fgets(buf, sizeof(buf) - 1, stdin) == NULL) {
             if (ferror(stdin)) {
                 debug((char *) "%s| %s: FATAL: fgets() failed! dying..... errno=%d (%s)\n", LogTime(), PROGRAM, ferror(stdin),
@@ -309,7 +305,7 @@ main(int argc, char *const argv[])
 
                 SEND_ERR("");
                 clean_args(&margs);
-                exit(1);    /* BIIG buffer */
+                exit(1);	/* BIIG buffer */
             }
             SEND_ERR("");
             clean_args(&margs);
@@ -424,7 +420,8 @@ strup(char *s)
 }
 
 #else
-#include <cstdlib>
+#include <stdio.h>
+#include <stdlib.h>
 int
 main(int argc, char *const argv[])
 {
@@ -439,4 +436,3 @@ main(int argc, char *const argv[])
     }
 }
 #endif
-
