@@ -1,41 +1,32 @@
-/*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
- *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
- */
-
 #ifndef SQUID_ANYP_PORTCFG_H
 #define SQUID_ANYP_PORTCFG_H
 
 #include "anyp/forward.h"
-#include "anyp/ProtocolVersion.h"
 #include "anyp/TrafficMode.h"
 #include "comm/Connection.h"
 
-#if USE_OPENSSL
+#if USE_SSL
 #include "ssl/gadgets.h"
 #endif
 
 namespace AnyP
 {
 
-class PortCfg : public RefCountable
+class PortCfg
 {
 public:
-    PortCfg();
+    PortCfg(const char *aProtocol);
     ~PortCfg();
-    AnyP::PortCfgPointer clone() const;
-#if USE_OPENSSL
+    AnyP::PortCfg *clone() const;
+#if USE_SSL
     /// creates, configures, and validates SSL context and related port options
     void configureSslServerContext();
 #endif
 
-    PortCfgPointer next;
+    PortCfg *next;
 
     Ip::Address s;
-    AnyP::ProtocolVersion transport; ///< transport protocol and version received by this port
+    char *protocol;            /* protocol name */
     char *name;                /* visible name */
     char *defaultsite;         /* default web site */
 
@@ -48,8 +39,6 @@ public:
 
     bool connection_auth_disabled; ///< Don't support connection oriented auth
 
-    bool ftp_track_dirs; ///< whether transactions should track FTP directories
-
     int vport;               ///< virtual port support. -1 if dynamic, >0 static
     int disable_pmtu_discovery;
 
@@ -67,7 +56,7 @@ public:
      */
     Comm::ConnectionPointer listenConn;
 
-#if USE_OPENSSL
+#if USE_SSL
     char *cert;
     char *key;
     int version;
@@ -78,7 +67,6 @@ public:
     char *capath;
     char *crlfile;
     char *dhfile;
-    char *tls_dh;
     char *sslflags;
     char *sslContextSessionId; ///< "session id context" for staticSslContext
     bool generateHostCertificates; ///< dynamically make host cert for sslBump
@@ -94,34 +82,21 @@ public:
     Ssl::X509_CRL_STACK_Pointer clientVerifyCrls; ///< additional CRL lists to use when verifying the client certificate
     Ssl::X509_NAME_STACK_Pointer clientCA; ///< CA certificates to use when verifying client certificates
     Ssl::DH_Pointer dhParams; ///< DH parameters for temporary/ephemeral DH key exchanges
-    char *eecdhCurve; ///< Elliptic curve for ephemeral EC-based DH key exchanges
     Ssl::ContextMethod contextMethod; ///< The context method (SSL_METHOD) to use when creating certificates
     long sslContextFlags; ///< flags modifying the use of SSL
     long sslOptions; ///< SSL engine options
 #endif
+
+    CBDATA_CLASS2(PortCfg); // namespaced
 };
 
 } // namespace AnyP
 
-/// list of Squid http_port configured
-extern AnyP::PortCfgPointer HttpPortList;
-
-#if USE_OPENSSL
-/// list of Squid https_port configured
-extern AnyP::PortCfgPointer HttpsPortList;
-#endif
-
-/// list of Squid ftp_port configured
-extern AnyP::PortCfgPointer FtpPortList;
-
-#if !defined(MAXTCPLISTENPORTS)
 // Max number of TCP listening ports
 #define MAXTCPLISTENPORTS 128
-#endif
 
 // TODO: kill this global array. Need to check performance of array vs list though.
 extern int NHttpSockets;
 extern int HttpSockets[MAXTCPLISTENPORTS];
 
 #endif /* SQUID_ANYP_PORTCFG_H */
-
